from resolwe.process import Cmd, IntegerField, Process, FileField

class WordCount(Process):
    """A Word Count process."""

    slug = "wc-basic"
    name = "Word Count"
    process_type = "data:wc"
    version = "1.0.0"
    requirements = {
        "expression-engine": "jinja",
    }

    class Input:
        """Input fields to process WordCount."""
        document = FileField(label="Document")

    class Output:
        """Output field of the process WordCount."""
        words = IntegerField(label="Number of words")

    def run(self, inputs, outputs):
        """Run the analysis."""
        input_doc = inputs.document.import_file()
        num_words = int((Cmd["wc"]["-w"] < input_doc)())
        outputs.words = num_words



from resolwe.process import Process

class Minimal(Process):
    """A minimal example process."""

    slug = "mini"
    name = "Minimalistic Process"
    process_type = "data:mini"
    version = "1.0.0"
    requirements = {
        "expression-engine": "jinja",
    }

    class Input:
        """Input fields to process Minimal."""
        pass

    class Output:
        """Output field of the process Minimal."""
        pass

    def run(self, inputs, outputs):
        """Run the analysis."""
        print("Hello bioinformatician!")



# pylint: disable=missing-docstring
from django.utils.text import slugify

from resolwe.flow.models import Process
from resolwe.flow.models.base import MAX_SLUG_LENGTH
from resolwe.flow.models.fields import MAX_SLUG_SEQUENCE_DIGITS
from resolwe.test import TestCase


class ManagerTest(TestCase):
    def setUp(self):
        super().setUp()

        self.data = {
            "name": "Test Process",
            "contributor": self.contributor,
            "type": "data:test",
            "version": 1,
        }

    def test_slug(self):
        p = Process.objects.create(**self.data)
        self.assertEqual(p.slug, "test-process")

        self.data["version"] = 2
        p = Process.objects.create(**self.data)
        self.assertEqual(p.slug, "test-process")

        p = Process.objects.create(**self.data)
        self.assertEqual(p.slug, "test-process-2")

        # Make sure slug is truncated properly.
        data = self.data.copy()
        data["name"] = "N" * (MAX_SLUG_LENGTH - MAX_SLUG_SEQUENCE_DIGITS - 2) + "-name"
        p = Process.objects.create(**data)
        self.assertEqual(p.slug, slugify(p.slug))



from resolwe.process import Cmd, DataField, IntegerField, Process, FileField


class UploadDocument(Process):
    """A Document Upload process."""

    slug = "upload-document"
    name = "Upload Document"
    process_type = "data:doc"
    version = "1.0.0"
    requirements = {
        "expression-engine": "jinja",
    }

    class Input:
        """Input fields to process UploadDocument."""
        in_doc = FileField(label="Input document")

    class Output:
        """Output field of the process UploadDocument."""
        out_doc = FileField(label="Output document")

    def run(self, inputs, outputs):
        """Run the analysis."""
        input_doc = inputs.in_doc.import_file()
        outputs.out_doc = input_doc


class WordCount(Process):
    """A Word Count process."""

    slug = "wc"
    name = "Word Count"
    process_type = "data:wc"
    version = "1.0.0"
    requirements = {
        "expression-engine": "jinja",
    }

    class Input:
        """Input fields to process WordCount."""
        document = DataField(data_type="doc", label="Document")

    class Output:
        """Output field of the process WordCount."""
        words = IntegerField(label="Number of words")

    def run(self, inputs, outputs):
        """Run the analysis."""
        document = inputs.document.output.out_doc.path
        num_words = int((Cmd["wc"]["-w"] < document)())
        outputs.words = num_words


class NumberOfLines(Process):
    """A Line Count process."""

    slug = "ln"
    name = "Number of Lines"
    process_type = "data:ln"
    version = "1.0.0"
    requirements = {
        "expression-engine": "jinja",
    }

    class Input:
        """Input fields to process NumberOfLines."""
        document = DataField(data_type="doc", label="Document")

    class Output:
        """Output field of the process NumberOfLines."""
        lines = IntegerField(label="Number of lines")

    def run(self, inputs, outputs):
        """Run the analysis."""
        document = inputs.document.output.out_doc.path
        num_lines = int((Cmd["wc"]["-l"] < document)())
        outputs.lines = num_lines
